@@ -122,6 +122,7 @@ html_box_accessible_initialize (AtkObject *obj, gpointer data)
 
 	ATK_OBJECT_CLASS (parent_class)->initialize (obj, data);
 
+	HTML_BOX_ACCESSIBLE (obj)->index = -1;
 	box = HTML_BOX (data);
 
 	if (box->parent) { 
@@ -252,6 +253,8 @@ html_box_accessible_get_index_in_parent (AtkObject *obj)
 	GObject *g_obj;
 
 	g_return_val_if_fail (HTML_IS_BOX_ACCESSIBLE (obj), -1);
+	if (HTML_BOX_ACCESSIBLE (obj)->index != -1)
+		return HTML_BOX_ACCESSIBLE (obj)->index;
 
 	atk_gobj = ATK_GOBJECT_ACCESSIBLE (obj);
 	g_obj = atk_gobject_accessible_get_object (atk_gobj);
