@@ -19,6 +19,7 @@
 
 #include <libgtkhtml/gtkhtml.h>
 #include "layout/htmlboxtext.h"
+#include "layout/htmlboxtable.h"
 #include "layout/htmlboxinline.h"
 #include "htmlboxblocktextaccessible.h"
 #include <libgail-util/gail-util.h>
@@ -186,6 +187,8 @@ append_text (HtmlBox *root,
 
 	if (!root)
 		return;
+	if (HTML_IS_BOX_TABLE (root))
+		return;
 
 	if (HTML_IS_BOX_TEXT (root)) {
 		text = html_box_text_get_text (HTML_BOX_TEXT (root), &len);
@@ -230,16 +233,74 @@ html_box_block_text_accessible_real_initialize (AtkObject *object,
 static gint
 html_box_block_text_accessible_get_n_children (AtkObject *obj)
 {
-	return 0;
+        AtkGObjectAccessible *atk_gobject;
+        HtmlBox *box;
+        gint n_children = 0;
+        GObject *g_obj;
+
+        g_return_val_if_fail (HTML_IS_BOX_ACCESSIBLE (obj), 0);
+        atk_gobject = ATK_GOBJECT_ACCESSIBLE (obj);
+        g_obj = atk_gobject_accessible_get_object (atk_gobject);
+        if (g_obj == NULL)
+                return 0;
+
+        g_return_val_if_fail (HTML_IS_BOX (g_obj), 0);
+        box = HTML_BOX (g_obj);
+
+        if (box) {
+                HtmlBox *child;
+
+                child = box->children;
+
+                while (child) {
+                        if (HTML_IS_BOX_TABLE (child))
+				n_children++;
+                        child = child->next;
+                }
+        }
+        return n_children;
 }
 
 static AtkObject*
 html_box_block_text_accessible_ref_child (AtkObject *obj,
                                           gint      i)
 {
-	return NULL;
-}
+        AtkGObjectAccessible *atk_gobject;
+        GObject *g_obj;
+        HtmlBox *box;
+        AtkObject *atk_child = NULL;
+        gint n_children = 0;
 
+        g_return_val_if_fail (HTML_IS_BOX_ACCESSIBLE (obj), NULL);
+        atk_gobject = ATK_GOBJECT_ACCESSIBLE (obj);
+        g_obj = atk_gobject_accessible_get_object (atk_gobject);
+        if (g_obj == NULL)
+                return NULL;
+
+        g_return_val_if_fail (HTML_IS_BOX (g_obj), NULL);
+        box = HTML_BOX (g_obj);
+
+        if (box) {
+                HtmlBox *child;
+
+                child = box->children;
+
+                while (child) {
+                        if (HTML_IS_BOX_TABLE (child)) {
+                        	if (n_children == i) {
+                               		atk_child = atk_gobject_accessible_for_object (G_OBJECT (child));
+					g_assert (HTML_IS_BOX_ACCESSIBLE (atk_child));
+					HTML_BOX_ACCESSIBLE (atk_child)->index = i;
+					g_object_ref (atk_child);
+					break;
+				}
+                        	n_children++;
+			}	
+                        child = child->next;
+                }
+        }
+        return atk_child;
+}
 
 static void
 html_box_block_text_accessible_text_interface_init (AtkTextIface *iface)
